@@ -213,7 +213,7 @@ final class ParserTest extends TestCase
     public function testRaisesAnExceptionForUnknownLongOption(): void
     {
         $this->expectException(UnknownOptionException::class);
-        $this->expectExceptionMessage('Unknown option "--foo"');
+        $this->expectExceptionMessage('Unknown option "--foo". Most similar options are --colors');
 
         (new Parser)->parse(
             [
@@ -225,6 +225,21 @@ final class ParserTest extends TestCase
         );
     }
 
+    public function testRaisesAnExceptionForUnknownLongOptionMultipleAlternatives(): void
+    {
+        $this->expectException(UnknownOptionException::class);
+        $this->expectExceptionMessage('Unknown option "--foo". Most similar options are --colors, --exec, --help, --config, --column');
+
+        (new Parser)->parse(
+            [
+                'command',
+                '--foo',
+            ],
+            '',
+            ['colors', 'columns', 'verbose', 'help', 'version', 'output', 'config', 'exec'],
+        );
+    }
+
     public function testRaisesAnExceptionForUnknownShortOption(): void
     {
         $this->expectException(UnknownOptionException::class);
